| Title: | Consult 'Grass GIS' Documentation in the RStudio Viewer or your Browser |
|---|---|
| Description: | A tool for easy viewing of the documentation of 'GRASS GIS' (see <https://grass.osgeo.org/>). Pages of the 'GRASS GIS' manuals found at <https://grass.osgeo.org/grass78/manuals/full_index.html> and at <https://grass.osgeo.org/grass78/manuals/addons/> can be viewed within the Viewer pane of 'RStudio', or be opened in the user's default browser. |
| Authors: | Valentin Lucet [aut, cre] |
| Maintainer: | Valentin Lucet <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0.9000 |
| Built: | 2026-05-12 08:01:09 UTC |
| Source: | https://github.com/VLucet/rgrassdoc |
A dataset containing the names and descriptions of all GRASS 7.8 modules and addons, scraped from the GRASS manual full index page.
grassmodules78grassmodules78
A data frame with 528 rows and 2 columns.
character, module name
character, module description
logical, whether the module is an addon
https://grass.osgeo.org/grass78/manuals/full_index.html https://grass.osgeo.org/grass78/manuals/addons/
Visualize a 'GRASS GIS' module manual page either in the RStudio viewer pane or in your browser.
man(module, viewer = .Options$grass.viewer, dir = tempdir()) browse(module, viewer = "browser", dir = tempdir())man(module, viewer = .Options$grass.viewer, dir = tempdir()) browse(module, viewer = "browser", dir = tempdir())
module |
(Character string, or simply the name of a 'GRASS GIS' module)
The function supports non standard evaluation (i.e. |
viewer |
(Character string) One of |
dir |
(Character string) The directory in which to store the cached
documentation (default to |
This function does not return anything and is used for its side effects.
## Not run: man("r.in.gdal") browse(r.reclass) ## End(Not run)## Not run: man("r.in.gdal") browse(r.reclass) ## End(Not run)
This set of function can be used to get the version used by the package or to set the desired version.
man_set_version(version = 7.8) man_get_version()man_set_version(version = 7.8) man_get_version()
version |
[Double] The desired version of GRASS (7.8, 7.9, etc...) |
The function 'man_get_version' will return the currently set version, and 'man_set_version' will do so invisibly.
man_set_version(7.9) man_get_version()man_set_version(7.9) man_get_version()